{ config, lib, pkgs, ... }:

{
  home.packages = [ pkgs.libsecret ];

  programs.msmtp.enable = true;
  programs.mbsync.enable = true;
  programs.neomutt = {
    enable = true;
    sidebar.enable = true;
    vimKeys = true;
    macros = [
      {
        action = "<shell-escape>mbsync -all<enter>";
        key = "S";
        map = [ "index" ];
      }
    ];
  };

  accounts.email = {
    maildirBasePath = "${config.xdg.dataHome}/mail";

    accounts = {
      molez = rec {
        primary = true;

        realName = "Michael Mandl";
        address = "mandlm@molez.net";

        userName = address;
        passwordCommand = "secret-tool lookup email mandlm@molez.net";

        imap = {
          host = "mail.molez.net";
          port = 993;
          tls.enable = true;
        };

        smtp = {
          host = "mail.molez.net";
          port = 465;
          tls.enable = true;
        };

        gpg = {
          key = "0x4AA25D647AA54CC7";
          signByDefault = true;
        };

        msmtp.enable = true;
        mbsync = {
          enable = true;
          create = "both";
          expunge = "both";
        };

        neomutt.enable = true;
      };
      swp = {
        realName = "Michael Mandl";
        address = "mandl@vi-bim.de";

        userName = "mandl";
        passwordCommand = "secret-tool lookup email mandl@vi-bim.de";

        imap = {
          host = "swpmail.softwareparadies.de";
          port = 993;
          tls.enable = true;
        };

        smtp = {
          host = "swpmail.softwareparadies.de";
          port = 465;
          tls.enable = true;
        };

        gpg = {
          key = "0x4E60F44227F611B4 ";
          signByDefault = true;
        };

        signature = {
          showSignature = "append";
          text = ''
            --
            Mit freundlichen Grüßen

            Michael Mandl
            Entwicklung
            ------------------------------------------
            swp software systems GmbH & Co. KG

            Königsbrücker Straße 124
            01099 Dresden
            Tel: 0351-492850
            Fax: 0351-4928550
            www: https://www.vi-bim.de

            Kennen Sie schon unsere FAQ-Wissensdatenbank? Einfach hier klicken:
            https://faq.vi-bim.de

            Unsere Datenschutzerklärung finden Sie unter https://datenschutz.vi-bim.de

            Registergericht: Amtsgericht Dresden HRA 3008
            persönlich haftender Gesellschafter:
            swp Beteiligungs GmbH
            Registergericht: Amtsgericht Dresden HRB 15 20 9
            Geschäftsführer: Holger Schönemann, Stefan Urlberger
          '';
        };

        msmtp.enable = true;
        mbsync = {
          enable = true;
          create = "both";
          expunge = "both";
        };

        neomutt.enable = true;
      };
    };
  };
}
